@@ -1,6 +1,6 @@
 package Langertha::Engine::Anthropic;
 # ABSTRACT: Anthropic API
-our $VERSION = '0.100';
+our $VERSION = '0.200';
 use Moose;
 use Carp qw( croak );
 use JSON::MaybeXS;
@@ -16,6 +16,7 @@ with 'Langertha::Role::'.$_ for (qw(
   Streaming
 ));
 
+
 sub default_response_size { 1024 }
 
 has api_key => (
@@ -28,25 +29,28 @@ sub _build_api_key {
     || croak "".(ref $self)." requires LANGERTHA_ANTHROPIC_API_KEY or api_key set";
 }
 
+
 has api_version => (
   is => 'ro',
   lazy_build => 1,
 );
 sub _build_api_version { '2023-06-01' }
 
-# New parameters (February 2026)
+
 has effort => (
   is => 'ro',
   isa => 'Str',
   predicate => 'has_effort',
 );
 
+
 has inference_geo => (
   is => 'ro',
   isa => 'Str',
   predicate => 'has_inference_geo',
 );
 
+
 sub update_request {
   my ( $self, $request ) = @_;
   $request->header('x-api-key', $self->api_key);
@@ -60,13 +64,7 @@ has '+url' => (
 );
 sub has_url { 1 }
 
-sub all_models {qw(
-  claude-opus-4-6-20250514
-  claude-sonnet-4-5-20250929
-  claude-haiku-4-5-20251001
-)}
-
-sub default_model { 'claude-sonnet-4-5-20250929' }
+sub default_model { 'claude-sonnet-4-6' }
 
 sub chat_request {
   my ( $self, $messages, %extra ) = @_;
@@ -102,9 +100,16 @@ sub chat_request {
 sub chat_response {
   my ( $self, $response ) = @_;
   my $data = $self->parse_response($response);
-  # tracing
   my @messages = @{$data->{content}};
-  return $messages[0]->{text};
+  require Langertha::Response;
+  return Langertha::Response->new(
+    content       => $messages[0]->{text} // '',
+    raw           => $data,
+    $data->{id} ? ( id => $data->{id} ) : (),
+    $data->{model} ? ( model => $data->{model} ) : (),
+    defined $data->{stop_reason} ? ( finish_reason => $data->{stop_reason} ) : (),
+    $data->{usage} ? ( usage => $data->{usage} ) : (),
+  );
 }
 
 sub stream_format { 'sse' }
@@ -250,6 +255,7 @@ sub list_models {
   return $opts{full} ? $models : \@model_ids;
 }
 
+
 # Tool calling support (MCP)
 
 sub format_tools {
@@ -268,6 +274,11 @@ sub response_tool_calls {
   return [grep { $_->{type} eq 'tool_use' } @{$data->{content} // []}];
 }
 
+sub extract_tool_call {
+  my ( $self, $tc ) = @_;
+  return ( $tc->{name}, $tc->{input} );
+}
+
 sub response_text_content {
   my ( $self, $data ) = @_;
   return join('', map { $_->{text} }
@@ -296,6 +307,9 @@ with 'Langertha::Role::Tools';
 
 __PACKAGE__->meta->make_immutable;
 
+
+1;
+
 __END__
 
 =pod
@@ -308,149 +322,101 @@ Langertha::Engine::Anthropic - Anthropic API
 
 =head1 VERSION
 
-version 0.100
+version 0.200
 
 =head1 SYNOPSIS
 
-  use Langertha::Engine::Anthropic;
+    use Langertha::Engine::Anthropic;
 
-  # Basic usage
-  my $claude = Langertha::Engine::Anthropic->new(
-    api_key => $ENV{ANTHROPIC_API_KEY},
-    model => 'claude-sonnet-4-5-20250929',
-    response_size => 4096,
-    temperature => 0.7,
-  );
+    my $claude = Langertha::Engine::Anthropic->new(
+        api_key      => $ENV{ANTHROPIC_API_KEY},
+        model        => 'claude-sonnet-4-6',
+        response_size => 4096,
+        temperature  => 0.7,
+    );
 
-  # Simple chat
-  my $response = $claude->simple_chat('Generate Perl Moose classes to represent GeoJSON data types');
-  print $response;
+    # Simple chat
+    my $response = $claude->simple_chat('Generate Perl Moose classes to represent GeoJSON data types');
+    print $response;
 
-  # Streaming
-  $claude->simple_chat_stream(sub {
-    my ($chunk) = @_;
-    print $chunk->content;
-  }, 'Tell me about Perl');
+    # Streaming
+    $claude->simple_chat_stream(sub {
+        my ($chunk) = @_;
+        print $chunk->content;
+    }, 'Tell me about Perl');
 
-  # Async with Future::AsyncAwait
-  use Future::AsyncAwait;
+    # Async with Future::AsyncAwait
+    use Future::AsyncAwait;
 
-  async sub ask_claude {
-    my $response = await $claude->simple_chat_f('What is the meaning of life?');
-    say $response;
-  }
+    async sub ask_claude {
+        my $response = await $claude->simple_chat_f('What is the meaning of life?');
+        say $response;
+    }
 
 =head1 DESCRIPTION
 
-This module provides access to Anthropic's Claude models via their API.
-Claude is a family of large language models known for their helpfulness,
-harmlessness, and honesty.
+Provides access to Anthropic's Claude models via their API. Claude is a
+family of large language models known for helpfulness, harmlessness, and
+honesty.
 
-B<Available Models (February 2026):>
-
-=over 4
-
-=item * B<claude-opus-4-6-20250514> - Most capable model with 1M token context, strongest coding, planning, and debugging capabilities. Released February 5, 2026. Best for complex tasks, code review, and agentic workflows.
-
-=item * B<claude-sonnet-4-5-20250929> - Balanced performance and speed (default). Released November 24, 2025. Excellent for most general-purpose tasks.
-
-=item * B<claude-haiku-4-5-20251001> - Fastest and most cost-efficient model. Matches Sonnet 4's performance on coding, computer use, and agent tasks while being significantly cheaper.
-
-=back
-
-The Claude model family is organized by capability: Haiku (fastest/cheapest), Sonnet (balanced), and Opus (most capable/expensive).
-
-B<Features:>
-
-=over 4
-
-=item * Streaming support (SSE-based)
-
-=item * System prompts
-
-=item * Temperature control
-
-=item * Response size limits (max_tokens)
-
-=item * Async/await support via Future::AsyncAwait
-
-=item * Dynamic model discovery via API
-
-=item * Advanced parameters: effort (thinking depth), inference_geo (data residency)
-
-=back
+Available models include C<claude-opus-4-6> (most capable), C<claude-sonnet-4-6>
+(balanced, default), and C<claude-haiku-4-5-20251001> (fastest). The default
+API endpoint is C<https://api.anthropic.com>.
 
 B<THIS API IS WORK IN PROGRESS>
 
-=head1 NEW PARAMETERS (FEBRUARY 2026)
+=head2 api_key
 
-Anthropic has introduced new parameters for enhanced control:
+The Anthropic API key. If not provided, reads from C<LANGERTHA_ANTHROPIC_API_KEY>
+environment variable. Get your key at L<https://console.anthropic.com/>. Required.
+
+=head2 api_version
+
+The Anthropic API version header sent with every request. Defaults to
+C<2023-06-01>.
 
 =head2 effort
 
-Controls the depth of thinking for reasoning models. Values: C<low>, C<medium>, C<high>.
+Controls the depth of thinking for reasoning models. Values: C<low>, C<medium>,
+C<high>. When set, passed as the C<effort> parameter in the API request.
 
-  my $claude = Langertha::Engine::Anthropic->new(
-    api_key => $ENV{ANTHROPIC_API_KEY},
-    model => 'claude-opus-4-6-20250514',
-    effort => 'high',  # More thorough reasoning
-  );
+    my $claude = Langertha::Engine::Anthropic->new(
+        api_key => $ENV{ANTHROPIC_API_KEY},
+        model   => 'claude-opus-4-6',
+        effort  => 'high',
+    );
 
 =head2 inference_geo
 
-Controls data residency for inference. Values: C<us>, C<eu>.
+Controls data residency for inference. Values: C<us>, C<eu>. When set, passed
+as the C<inference_geo> parameter to keep processing in the specified region.
 
-  my $claude = Langertha::Engine::Anthropic->new(
-    api_key => $ENV{ANTHROPIC_API_KEY},
-    model => 'claude-sonnet-4-5-20250929',
-    inference_geo => 'eu',  # Process in EU region
-  );
+    my $claude = Langertha::Engine::Anthropic->new(
+        api_key       => $ENV{ANTHROPIC_API_KEY},
+        inference_geo => 'eu',
+    );
 
-=head1 LISTING AVAILABLE MODELS
+=head2 list_models
 
-Dynamically fetch available models from the Anthropic API (with cursor pagination):
+    my $model_ids = $engine->list_models;
+    my $models    = $engine->list_models(full => 1);
+    my $models    = $engine->list_models(force_refresh => 1);
 
-  # Get simple list of model IDs
-  my $model_ids = $engine->list_models;
-  # Returns: ['claude-opus-4-6-20250514', 'claude-sonnet-4-5-20250929', ...]
-
-  # Get full model objects with metadata
-  my $models = $engine->list_models(full => 1);
-  # Returns: [{id => '...', display_name => '...', created_at => '...'}, ...]
-
-  # Force refresh (bypass cache)
-  my $models = $engine->list_models(force_refresh => 1);
-
-B<Caching:> Results are cached for 1 hour by default. Configure the TTL:
-
-  my $engine = Langertha::Engine::Anthropic->new(
-    api_key => $ENV{ANTHROPIC_API_KEY},
-    models_cache_ttl => 1800, # 30 minutes
-  );
-
-  # Clear the cache manually
-  $engine->clear_models_cache;
-
-B<Deprecation Notice:> The C<all_models()> method returns a hardcoded list and
-is deprecated. Use C<list_models()> for up-to-date model availability.
-
-=head1 GETTING AN API KEY
-
-Sign up at L<https://console.anthropic.com/> and generate an API key.
-
-Set the environment variable:
-
-  export ANTHROPIC_API_KEY=your-key-here
-  # Or use LANGERTHA_ANTHROPIC_API_KEY
+Fetches available models from the Anthropic API using cursor pagination.
+Returns an ArrayRef of model ID strings by default, or full model objects
+when C<full => 1> is passed. Results are cached for C<models_cache_ttl>
+seconds (default: 3600). Pass C<force_refresh => 1> to bypass the cache.
 
 =head1 SEE ALSO
 
-=over 4
+=over
 
 =item * L<https://docs.anthropic.com/> - Official Anthropic documentation
 
 =item * L<Langertha::Role::Chat> - Chat interface methods
 
+=item * L<Langertha::Role::Tools> - MCP tool calling interface
+
 =item * L<Langertha> - Main Langertha documentation
 
 =back
