@@ -1,11 +1,12 @@
 package Langertha::Engine::Whisper;
 # ABSTRACT: Whisper compatible transcription server
-our $VERSION = '0.100';
+our $VERSION = '0.200';
 use Moose;
 use Carp qw( croak );
 
 extends 'Langertha::Engine::OpenAI';
 
+
 sub default_transcription_model { '' }
 
 has '+url' => (
@@ -19,6 +20,7 @@ sub _build_supported_operations {[qw(
   createTranslation
 )]}
 
+
 1;
 
 __END__
@@ -33,25 +35,45 @@ Langertha::Engine::Whisper - Whisper compatible transcription server
 
 =head1 VERSION
 
-version 0.100
+version 0.200
 
 =head1 SYNOPSIS
 
-  use Langertha::Engine::Whisper;
+    use Langertha::Engine::Whisper;
 
-  my $whisper = Langertha::Engine::Whisper->new(
-    url => $ENV{WHISPER_URL},
-  );
+    my $whisper = Langertha::Engine::Whisper->new(
+        url => $ENV{WHISPER_URL},
+    );
 
-  print($whisper->simple_transcription('recording.ogg'));
+    print $whisper->simple_transcription('recording.ogg');
 
 =head1 DESCRIPTION
 
+Provides access to a self-hosted Whisper-compatible transcription server.
+Extends L<Langertha::Engine::OpenAI> and supports the C<createTranscription>
+and C<createTranslation> operations.
+
+C<url> is required. The API key defaults to C<'whisper'>. The transcription
+model defaults to an empty string so the server uses its built-in default.
+
+See L<https://github.com/fedirz/faster-whisper-server> for a compatible
+server implementation.
+
 B<THIS API IS WORK IN PROGRESS>
 
-=head1 HOW TO INSTALL FASTER WHISPER
+=head1 SEE ALSO
 
-L<https://github.com/fedirz/faster-whisper-server>
+=over
+
+=item * L<https://github.com/fedirz/faster-whisper-server> - faster-whisper-server
+
+=item * L<Langertha::Engine::OpenAI> - Parent engine
+
+=item * L<Langertha::Engine::Groq> - Groq's hosted Whisper transcription
+
+=item * L<Langertha> - Main Langertha documentation
+
+=back
 
 =head1 SUPPORT
 
