@@ -1,6 +1,6 @@
 package Langertha::Role::Chat;
 # ABSTRACT: Role for APIs with normal chat functionality
-our $VERSION = '0.100';
+our $VERSION = '0.200';
 use Moose::Role;
 use Future::AsyncAwait;
 use Carp qw( croak );
@@ -10,6 +10,7 @@ requires qw(
   chat_response
 );
 
+
 has chat_model => (
   is => 'ro',
   isa => 'Str',
@@ -22,11 +23,13 @@ sub _build_chat_model {
   return $self->model;
 }
 
+
 sub chat {
   my ( $self, @messages ) = @_;
   return $self->chat_request($self->chat_messages(@messages));
 }
 
+
 sub chat_messages {
   my ( $self, @messages ) = @_;
   return [$self->has_system_prompt
@@ -40,6 +43,7 @@ sub chat_messages {
     } @messages];
 }
 
+
 sub simple_chat {
   my ( $self, @messages ) = @_;
   my $request = $self->chat(@messages);
@@ -47,6 +51,7 @@ sub simple_chat {
   return $request->response_call->($response);
 }
 
+
 sub chat_stream {
   my ( $self, @messages ) = @_;
   croak "".(ref $self)." does not support streaming"
@@ -54,6 +59,7 @@ sub chat_stream {
   return $self->chat_stream_request($self->chat_messages(@messages));
 }
 
+
 sub simple_chat_stream {
   my ( $self, $callback, @messages ) = @_;
   croak "simple_chat_stream requires a callback as first argument"
@@ -63,6 +69,7 @@ sub simple_chat_stream {
   return join('', map { $_->content } @$chunks);
 }
 
+
 sub simple_chat_stream_iterator {
   my ( $self, @messages ) = @_;
   require Langertha::Stream;
@@ -71,6 +78,7 @@ sub simple_chat_stream_iterator {
   return Langertha::Stream->new(chunks => $chunks);
 }
 
+
 # Future-based async methods
 
 has _async_loop => (
@@ -111,11 +119,13 @@ async sub simple_chat_f {
   return $request->response_call->($response);
 }
 
+
 sub simple_chat_stream_f {
   my ($self, @messages) = @_;
   return $self->simple_chat_stream_realtime_f(undef, @messages);
 }
 
+
 async sub simple_chat_stream_realtime_f {
   my ($self, $chunk_callback, @messages) = @_;
 
@@ -166,6 +176,7 @@ async sub simple_chat_stream_realtime_f {
   return ($content, \@all_chunks);
 }
 
+
 sub _process_stream_buffer {
   my ($self, $buffer_ref, $format, $final) = @_;
 
@@ -198,6 +209,9 @@ sub _process_stream_buffer {
   return \@chunks;
 }
 
+with 'Langertha::Role::Langfuse';
+
+
 1;
 
 __END__
@@ -212,154 +226,187 @@ Langertha::Role::Chat - Role for APIs with normal chat functionality
 
 =head1 VERSION
 
-version 0.100
+version 0.200
 
 =head1 SYNOPSIS
 
-  # Synchronous chat
-  my $response = $engine->simple_chat('Hello, how are you?');
+    # Synchronous chat
+    my $response = $engine->simple_chat('Hello, how are you?');
 
-  # Streaming with callback
-  $engine->simple_chat_stream(sub {
-    my ($chunk) = @_;
-    print $chunk->content;
-  }, 'Tell me a story');
+    # Streaming with callback
+    $engine->simple_chat_stream(sub {
+        my ($chunk) = @_;
+        print $chunk->content;
+    }, 'Tell me a story');
 
-  # Streaming with iterator
-  my $stream = $engine->simple_chat_stream_iterator('Tell me a story');
-  while (my $chunk = $stream->next) {
-    print $chunk->content;
-  }
+    # Streaming with iterator
+    my $stream = $engine->simple_chat_stream_iterator('Tell me a story');
+    while (my $chunk = $stream->next) {
+        print $chunk->content;
+    }
 
-  # Async with Future (traditional style)
-  my $future = $engine->simple_chat_f('Hello');
-  my $response = $future->get;
+    # Async with Future (traditional style)
+    my $future = $engine->simple_chat_f('Hello');
+    my $response = $future->get;
 
-  # Async with Future::AsyncAwait (recommended)
-  use Future::AsyncAwait;
+    # Async with Future::AsyncAwait (recommended)
+    use Future::AsyncAwait;
 
-  async sub chat_example {
-    my ($engine) = @_;
-    my $response = await $engine->simple_chat_f('Hello');
-    say $response;
-  }
+    async sub chat_example {
+        my ($engine) = @_;
+        my $response = await $engine->simple_chat_f('Hello');
+        say $response;
+    }
 
-  # Async streaming with Future::AsyncAwait
-  async sub stream_example {
-    my ($engine) = @_;
-    my ($content, $chunks) = await $engine->simple_chat_stream_realtime_f(
-      sub { print shift->content },
-      'Tell me a story'
-    );
-    say "\nTotal chunks: ", scalar @$chunks;
-  }
+    # Async streaming with real-time callback
+    async sub stream_example {
+        my ($engine) = @_;
+        my ($content, $chunks) = await $engine->simple_chat_stream_realtime_f(
+            sub { print shift->content },
+            'Tell me a story'
+        );
+        say "\nTotal chunks: ", scalar @$chunks;
+    }
 
 =head1 DESCRIPTION
 
 This role provides chat functionality for LLM engines. It includes both
-synchronous and asynchronous (Future-based) methods for chat and streaming.
+synchronous and asynchronous (L<Future>-based) methods for chat and streaming.
+
+The Future-based C<_f> methods are implemented using L<Future::AsyncAwait> and
+L<Net::Async::HTTP>. These modules are loaded lazily only when you call a C<_f>
+method, so synchronous-only usage does not require them.
+
+=head2 chat_model
+
+The model name used for chat requests. Lazily defaults to C<default_chat_model>
+if the engine provides it, otherwise falls back to the general C<model>
+attribute from L<Langertha::Role::Models>.
+
+=head2 chat
+
+    my $request = $engine->chat(@messages);
+
+Builds and returns a chat HTTP request object. Messages may be plain strings
+(treated as C<user> role) or HashRefs with C<role> and C<content> keys. A
+system prompt from L<Langertha::Role::SystemPrompt> is prepended automatically.
+
+=head2 chat_messages
+
+    my $messages = $engine->chat_messages(@messages);
+
+Normalises C<@messages> into the canonical ArrayRef-of-HashRef format expected
+by C<chat_request>. Plain strings become C<{ role =E<gt> 'user', content =E<gt>
+$string }>. If the engine has a C<system_prompt> set it is prepended as a
+C<system> message.
 
 =head2 simple_chat
 
-  my $response = $engine->simple_chat(@messages);
+    my $response = $engine->simple_chat(@messages);
+    my $response = $engine->simple_chat('Hello, how are you?');
 
-Sends a chat request and returns the response content. Blocks until complete.
+Sends a synchronous chat request and returns the response text. Blocks until
+the request completes.
+
+=head2 chat_stream
+
+    my $request = $engine->chat_stream(@messages);
+
+Builds and returns a streaming chat HTTP request object. Croaks if the engine
+does not implement C<chat_stream_request>. Use L</simple_chat_stream> or
+L</simple_chat_stream_iterator> to execute the request.
 
 =head2 simple_chat_stream
 
-  my $content = $engine->simple_chat_stream($callback, @messages);
+    my $content = $engine->simple_chat_stream($callback, @messages);
 
-Sends a streaming chat request. Calls C<$callback> with each chunk as it
-arrives. Returns the complete content when done. Blocks until complete.
+    $engine->simple_chat_stream(sub {
+        my ($chunk) = @_;
+        print $chunk->content;
+    }, 'Tell me a story');
+
+Sends a synchronous streaming chat request. Calls C<$callback> with each
+L<Langertha::Stream::Chunk> as it arrives. Returns the complete concatenated
+content string when done. Blocks until the stream completes.
 
 =head2 simple_chat_stream_iterator
 
-  my $stream = $engine->simple_chat_stream_iterator(@messages);
+    my $stream = $engine->simple_chat_stream_iterator(@messages);
+    while (my $chunk = $stream->next) {
+        print $chunk->content;
+    }
 
-Returns a L<Langertha::Stream> iterator object. Blocks while fetching,
-then allows iteration over chunks.
+Returns a L<Langertha::Stream> iterator. The full response is fetched
+synchronously and buffered; iteration yields each L<Langertha::Stream::Chunk>
+in order.
 
 =head2 simple_chat_f
 
-  # Traditional Future style
-  my $future = $engine->simple_chat_f(@messages);
-  my $response = $future->get;
+    # Traditional Future style
+    my $response = $engine->simple_chat_f(@messages)->get;
 
-  # With async/await (recommended)
-  use Future::AsyncAwait;
-  async sub my_chat {
-    my $response = await $engine->simple_chat_f(@messages);
-    return $response;
-  }
+    # With async/await (recommended)
+    use Future::AsyncAwait;
+    async sub my_chat {
+        my $response = await $engine->simple_chat_f(@messages);
+        return $response;
+    }
 
-Async version of C<simple_chat>. Returns a L<Future> that resolves to
-the response content. Implemented using L<Future::AsyncAwait> for clean
-async/await syntax.
+Async version of L</simple_chat>. Returns a L<Future> that resolves to the
+response text. Uses L<Net::Async::HTTP> internally; loaded lazily on first call.
 
 =head2 simple_chat_stream_f
 
-  my $future = $engine->simple_chat_stream_f(@messages);
-  my ($content, $chunks) = $future->get;
+    my ($content, $chunks) = $engine->simple_chat_stream_f(@messages)->get;
 
-Async streaming without real-time callback. Returns a L<Future> that
-resolves to the complete content and an arrayref of all chunks.
+Async streaming without a real-time callback. Convenience wrapper around
+L</simple_chat_stream_realtime_f> with C<undef> as the callback. Returns a
+L<Future> that resolves to C<($content, \@chunks)>.
 
 =head2 simple_chat_stream_realtime_f
 
-  # Traditional Future style
-  my $future = $engine->simple_chat_stream_realtime_f($callback, @messages);
-  my ($content, $chunks) = $future->get;
+    # With async/await (recommended)
+    use Future::AsyncAwait;
+    async sub my_stream {
+        my ($content, $chunks) = await $engine->simple_chat_stream_realtime_f(
+            sub { print shift->content },
+            @messages
+        );
+        return $content;
+    }
 
-  # With async/await (recommended)
-  use Future::AsyncAwait;
-  async sub my_stream {
-    my ($content, $chunks) = await $engine->simple_chat_stream_realtime_f(
-      sub { print shift->content },  # Real-time callback
-      @messages
-    );
-    return $content;
-  }
+    # Traditional Future style
+    my $future = $engine->simple_chat_stream_realtime_f($callback, @messages);
+    my ($content, $chunks) = $future->get;
 
-Async streaming with real-time callback. The C<$callback> is called with
-each L<Langertha::Stream::Chunk> as it arrives from the server. Returns
-a L<Future> that resolves to the complete content and all chunks.
+Async streaming with real-time callback. C<$callback> is called with each
+L<Langertha::Stream::Chunk> as it arrives from the server. Returns a L<Future>
+that resolves to C<($content, \@chunks)> where C<$content> is the full
+concatenated text.
 
 This is the recommended method for real-time streaming in async applications.
-Implemented using L<Future::AsyncAwait> for clean async/await syntax.
+Pass C<undef> as the callback (or use L</simple_chat_stream_f>) if you only
+need the final result.
 
-=head1 ASYNC IMPLEMENTATION
+=head1 SEE ALSO
 
-The Future-based methods are implemented using L<Future::AsyncAwait>, which
-provides clean async/await syntax. Internally, they use L<IO::Async> and
-L<Net::Async::HTTP> for non-blocking I/O. These modules are loaded lazily
-only when you call one of the C<_f> methods, so synchronous usage doesn't
-require them.
+=over
 
-All C<_f> methods are defined with C<async sub>, allowing you to use
-C<await> when calling them from your own async subroutines.
+=item * L<Langertha> - Main Langertha documentation
 
-=head2 Integration with Mojolicious
+=item * L<Langertha::Role::Streaming> - Stream parsing (SSE / NDJSON)
 
-For Mojolicious applications, use L<Future::Mojo> to bridge the event loops:
+=item * L<Langertha::Role::Tools> - Tool calling on top of chat
 
-  use Future::Mojo;
-  use Langertha::Engine::OpenAI;
+=item * L<Langertha::Role::SystemPrompt> - System prompt injection
 
-  my $engine = Langertha::Engine::OpenAI->new(...);
+=item * L<Langertha::Role::Models> - Model selection
 
-  # Get the Future and use it with Mojo
-  my $future = $engine->simple_chat_stream_realtime_f(
-    sub { print shift->content },
-    'Hello!'
-  );
+=item * L<Langertha::Stream> - Stream iterator
 
-  $future->on_done(sub {
-    my ($content, $chunks) = @_;
-    # Handle completion
-  });
+=item * L<Langertha::Stream::Chunk> - Individual stream chunk
 
-  # Run the IO::Async loop (or integrate with Mojo::IOLoop)
-  $engine->_async_loop->run;
+=back
 
 =head1 SUPPORT
 
