@@ -1,6 +1,6 @@
 package Langertha::Role::ContextSize;
 # ABSTRACT: Role for an engine where you can specify the context size (in tokens)
-our $VERSION = '0.100';
+our $VERSION = '0.200';
 use Moose::Role;
 
 has context_size => (
@@ -9,6 +9,7 @@ has context_size => (
   predicate => 'has_context_size',
 );
 
+
 sub get_context_size {
   my ( $self ) = @_;
   return $self->context_size if $self->has_context_size;
@@ -16,6 +17,8 @@ sub get_context_size {
   return;
 }
 
+
+
 1;
 
 __END__
@@ -30,7 +33,30 @@ Langertha::Role::ContextSize - Role for an engine where you can specify the cont
 
 =head1 VERSION
 
-version 0.100
+version 0.200
+
+=head2 context_size
+
+The maximum context size in tokens to use for requests. Optional. When not set,
+the engine uses its own C<default_context_size> if available, or omits the
+parameter from the request.
+
+=head2 get_context_size
+
+    my $size = $engine->get_context_size;
+
+Returns the effective context size: the explicit C<context_size> if set,
+otherwise the engine's C<default_context_size>, otherwise C<undef>.
+
+=head1 SEE ALSO
+
+=over
+
+=item * L<Langertha> - Main Langertha documentation
+
+=item * L<Langertha::Role::ResponseSize> - Limit response tokens
+
+=back
 
 =head1 SUPPORT
 
