@@ -1,16 +1,19 @@
 package Langertha::Role::JSON;
 # ABSTRACT: Role for JSON
-our $VERSION = '0.100';
+our $VERSION = '0.200';
 use Moose::Role;
 use JSON::MaybeXS;
 
 sub json { shift->_json }
+
+
 has _json => (
   is => 'ro',
   lazy_build => 1,
 );
 sub _build__json { JSON::MaybeXS->new( utf8 => 1, canonical => 1 ) }
 
+
 1;
 
 __END__
@@ -25,7 +28,28 @@ Langertha::Role::JSON - Role for JSON
 
 =head1 VERSION
 
-version 0.100
+version 0.200
+
+=head2 json
+
+    my $data = $engine->json->decode($json_string);
+    my $json_string = $engine->json->encode($data);
+
+Returns the shared L<JSON::MaybeXS> instance configured with C<utf8> and
+C<canonical> encoding. Used internally by L<Langertha::Role::HTTP> and
+L<Langertha::Role::Streaming> for all JSON serialization.
+
+=head1 SEE ALSO
+
+=over
+
+=item * L<Langertha> - Main Langertha documentation
+
+=item * L<Langertha::Role::HTTP> - HTTP role that requires this
+
+=item * L<JSON::MaybeXS> - The JSON backend used
+
+=back
 
 =head1 SUPPORT
 
