@@ -1,6 +1,6 @@
 package Langertha::Role::OpenAPI;
 # ABSTRACT: Role for APIs with OpenAPI definition
-our $VERSION = '0.100';
+our $VERSION = '0.200';
 use Moose::Role;
 
 use Carp qw( croak );
@@ -33,6 +33,7 @@ sub _build_openapi {
   );
 }
 
+
 has supported_operations => (
   is => 'ro',
   isa => 'ArrayRef[Str]',
@@ -43,6 +44,7 @@ sub _build_supported_operations {
   return [];
 }
 
+
 sub can_operation {
   my ( $self, $operationId ) = @_;
   return 1 unless scalar @{$self->supported_operations} > 0;
@@ -50,6 +52,7 @@ sub can_operation {
   return $so{$operationId};
 }
 
+
 sub get_operation {
   my ( $self, $operationId ) = @_;
   croak "".(ref $self)." runs in compatibility mode and is unable to perform this OpenAPI operation"
@@ -68,6 +71,7 @@ sub get_operation {
   return ( uc($method), $url.$path, $content_type );
 }
 
+
 sub generate_request {
   my ( $self, $operationId, $response_call, %args ) = @_;
   my ( $method, $url, $content_type ) = $self->get_operation($operationId);
@@ -75,6 +79,8 @@ sub generate_request {
   return $self->generate_http_request( $method, $url, $response_call, %args );
 }
 
+
+
 1;
 
 __END__
@@ -89,7 +95,54 @@ Langertha::Role::OpenAPI - Role for APIs with OpenAPI definition
 
 =head1 VERSION
 
-version 0.100
+version 0.200
+
+=head2 openapi
+
+The L<OpenAPI::Modern> instance loaded from the engine's C<openapi_file>. Built
+lazily on first use. Only YAML format OpenAPI specs are currently supported.
+
+=head2 supported_operations
+
+ArrayRef of C<operationId> strings that this engine instance supports. When
+non-empty, only listed operations are permitted; all others croak. Defaults to
+an empty ArrayRef (all operations allowed). Used to restrict engines that run in
+a limited compatibility mode.
+
+=head2 can_operation
+
+    if ($engine->can_operation('createChatCompletion')) { ... }
+
+Returns true if the given C<$operationId> is supported by this engine. Always
+returns true when C<supported_operations> is empty (unrestricted mode).
+
+=head2 get_operation
+
+    my ($method, $url, $content_type) = $engine->get_operation($operationId);
+
+Looks up an operation by C<$operationId> in the OpenAPI spec and returns the
+HTTP method, full URL, and content type as a three-element list. Croaks if the
+operation is not in C<supported_operations>.
+
+=head2 generate_request
+
+    my $request = $engine->generate_request($operationId, $response_call, %args);
+
+Generates an HTTP request for the named OpenAPI C<$operationId>. Resolves the
+method, URL, and content type from the spec, then delegates to
+L<Langertha::Role::HTTP/generate_http_request>.
+
+=head1 SEE ALSO
+
+=over
+
+=item * L<Langertha> - Main Langertha documentation
+
+=item * L<Langertha::Role::HTTP> - HTTP request building
+
+=item * L<OpenAPI::Modern> - OpenAPI spec handling
+
+=back
 
 =head1 SUPPORT
 
