@@ -1,6 +1,6 @@
 package Langertha::Role::ResponseSize;
 # ABSTRACT: Role for an engine where you can specify the response size (in tokens)
-our $VERSION = '0.100';
+our $VERSION = '0.200';
 use Moose::Role;
 
 has response_size => (
@@ -9,6 +9,7 @@ has response_size => (
   predicate => 'has_response_size',
 );
 
+
 sub get_response_size {
   my ( $self ) = @_;
   return $self->response_size if $self->has_response_size;
@@ -16,6 +17,8 @@ sub get_response_size {
   return;
 }
 
+
+
 1;
 
 __END__
@@ -30,7 +33,30 @@ Langertha::Role::ResponseSize - Role for an engine where you can specify the res
 
 =head1 VERSION
 
-version 0.100
+version 0.200
+
+=head2 response_size
+
+Maximum number of tokens to generate in the response. Optional. When not set,
+the engine uses its own C<default_response_size> if available, or omits the
+parameter from the request.
+
+=head2 get_response_size
+
+    my $size = $engine->get_response_size;
+
+Returns the effective response size: the explicit C<response_size> if set,
+otherwise the engine's C<default_response_size>, otherwise C<undef>.
+
+=head1 SEE ALSO
+
+=over
+
+=item * L<Langertha> - Main Langertha documentation
+
+=item * L<Langertha::Role::ContextSize> - Limit total context tokens
+
+=back
 
 =head1 SUPPORT
 
